@@ -1,21 +1,11 @@
 #!/bin/bash
 
-function kolla_kubernetes {
-    KUBE_TOKEN=$(</var/run/secrets/kubernetes.io/serviceaccount/token)
-    bootstrap_url=$(curl -sSk -H "Authorization: Bearer $KUBE_TOKEN" https://$KUBERNETES_SERVICE_HOST:$KUBERNETES_PORT_443_TCPORT/api/v1/namespaces/default/pods | grep /api/v1/namespaces/default/pods/keystone-bootstrap | cut -d '"' -f 4) || true
-    KEYSTONE_BOOTSTRAPPED=$(curl -sSk -H "Authorization: Bearer $KUBE_TOKEN" https://$KUBERNETES_SERVICE_HOST:$KUBERNETES_PORT_443_TCPORT$bootstrap_url | python -c 'import json,sys;obj=json.load(sys.stdin);print obj["status"]["phase"]') || KEYSTONE_BOOTSTRAPPED='Succeeded'
-
-    if [[ "$KEYSTONE_BOOTSTRAPPED" != "Succeeded" ]]; then
-        echo "Keystone bootstrapping isn't complete"
-        exit 1
-    fi
-}
-
 # NOTE(pbourke): httpd will not clean up after itself in some cases which
 # results in the container not being able to restart. (bug #1489676, 1557036)
 if [[ "${KOLLA_BASE_DISTRO}" =~ debian|ubuntu ]]; then
     # Loading Apache2 ENV variables
     . /etc/apache2/envvars
+    install -d /var/run/apache2/
     rm -rf /var/run/apache2/*
 else
     rm -rf /var/run/httpd/* /run/httpd/* /tmp/httpd*
@@ -67,10 +57,3 @@ if [[ "${!KOLLA_BOOTSTRAP[@]}" ]]; then
 fi
 
 ARGS="-DFOREGROUND"
-
-#***** KOLLA-KUBERNETES *****
-# TODO: Add a kolla_kubernetes script at build time when templating is complete
-if [[ "${!KOLLA_KUBERNETES[@]}" ]]; then
-    kolla_kubernetes
-fi
-#***** KOLLA-KUBERNETES *****
