@@ -65,7 +65,8 @@ class TasksTest(base.TestCase):
         pusher = build.PushTask(self.conf, self.image)
         pusher.run()
         mock_client().push.assert_called_once_with(
-            self.image.canonical_name, stream=True, insecure_registry=True)
+            self.image.canonical_name, decode=True,
+            stream=True, insecure_registry=True)
 
     @mock.patch('docker.version', '3.0.0')
     @mock.patch.dict(os.environ, clear=True)
@@ -75,19 +76,20 @@ class TasksTest(base.TestCase):
         pusher = build.PushTask(self.conf, self.image)
         pusher.run()
         mock_client().push.assert_called_once_with(
-            self.image.canonical_name, stream=True)
+            self.image.canonical_name, decode=True, stream=True)
         self.assertTrue(pusher.success)
 
     @mock.patch('docker.version', '3.0.0')
     @mock.patch.dict(os.environ, clear=True)
     @mock.patch('docker.APIClient')
     def test_push_image_failure(self, mock_client):
+        """failure on connecting Docker API"""
         self.dc = mock_client
         mock_client().push.side_effect = Exception
         pusher = build.PushTask(self.conf, self.image)
         pusher.run()
         mock_client().push.assert_called_once_with(
-            self.image.canonical_name, stream=True)
+            self.image.canonical_name, decode=True, stream=True)
         self.assertFalse(pusher.success)
         self.assertEqual(build.STATUS_PUSH_ERROR, self.image.status)
 
@@ -95,12 +97,13 @@ class TasksTest(base.TestCase):
     @mock.patch.dict(os.environ, clear=True)
     @mock.patch('docker.APIClient')
     def test_push_image_failure_retry(self, mock_client):
+        """failure on connecting Docker API, success on retry"""
         self.dc = mock_client
         mock_client().push.side_effect = [Exception, []]
         pusher = build.PushTask(self.conf, self.image)
         pusher.run()
         mock_client().push.assert_called_once_with(
-            self.image.canonical_name, stream=True)
+            self.image.canonical_name, decode=True, stream=True)
         self.assertFalse(pusher.success)
         self.assertEqual(build.STATUS_PUSH_ERROR, self.image.status)
 
@@ -111,6 +114,44 @@ class TasksTest(base.TestCase):
         self.assertTrue(pusher.success)
         self.assertEqual(build.STATUS_BUILT, self.image.status)
 
+    @mock.patch('docker.version', '3.0.0')
+    @mock.patch.dict(os.environ, clear=True)
+    @mock.patch('docker.APIClient')
+    def test_push_image_failure_error(self, mock_client):
+        """Docker connected, failure to push"""
+        self.dc = mock_client
+        mock_client().push.return_value = [{'errorDetail': {'message':
+                                                            'mock push fail'}}]
+        pusher = build.PushTask(self.conf, self.image)
+        pusher.run()
+        mock_client().push.assert_called_once_with(
+            self.image.canonical_name, decode=True, stream=True)
+        self.assertFalse(pusher.success)
+        self.assertEqual(build.STATUS_PUSH_ERROR, self.image.status)
+
+    @mock.patch('docker.version', '3.0.0')
+    @mock.patch.dict(os.environ, clear=True)
+    @mock.patch('docker.APIClient')
+    def test_push_image_failure_error_retry(self, mock_client):
+        """Docker connected, failure to push, success on retry"""
+        self.dc = mock_client
+        mock_client().push.return_value = [{'errorDetail': {'message':
+                                                            'mock push fail'}}]
+        pusher = build.PushTask(self.conf, self.image)
+        pusher.run()
+        mock_client().push.assert_called_once_with(
+            self.image.canonical_name, decode=True, stream=True)
+        self.assertFalse(pusher.success)
+        self.assertEqual(build.STATUS_PUSH_ERROR, self.image.status)
+
+        # Try again, this time without exception.
+        mock_client().push.return_value = [{'stream': 'mock push passes'}]
+        pusher.reset()
+        pusher.run()
+        self.assertEqual(2, mock_client().push.call_count)
+        self.assertTrue(pusher.success)
+        self.assertEqual(build.STATUS_BUILT, self.image.status)
+
     @mock.patch.dict(os.environ, clear=True)
     @mock.patch('docker.APIClient')
     def test_build_image(self, mock_client):
@@ -120,12 +161,29 @@ class TasksTest(base.TestCase):
         builder.run()
 
         mock_client().build.assert_called_once_with(
-            path=self.image.path, tag=self.image.canonical_name,
-            nocache=False, rm=True, pull=True, forcerm=True,
+            path=self.image.path, tag=self.image.canonical_name, decode=True,
+            network_mode=None, nocache=False, rm=True, pull=True, forcerm=True,
             buildargs=None)
 
         self.assertTrue(builder.success)
 
+    @mock.patch.dict(os.environ, clear=True)
+    @mock.patch('docker.APIClient')
+    def test_build_image_with_network_mode(self, mock_client):
+        self.dc = mock_client
+        push_queue = mock.Mock()
+        self.conf.set_override('network_mode', 'host')
+
+        builder = build.BuildTask(self.conf, self.image, push_queue)
+        builder.run()
+
+        mock_client().build.assert_called_once_with(
+            path=self.image.path, tag=self.image.canonical_name, decode=True,
+            network_mode='host', nocache=False, rm=True, pull=True,
+            forcerm=True, buildargs=None)
+
+        self.assertTrue(builder.success)
+
     @mock.patch.dict(os.environ, clear=True)
     @mock.patch('docker.APIClient')
     def test_build_image_with_build_arg(self, mock_client):
@@ -140,8 +198,8 @@ class TasksTest(base.TestCase):
         builder.run()
 
         mock_client().build.assert_called_once_with(
-            path=self.image.path, tag=self.image.canonical_name,
-            nocache=False, rm=True, pull=True, forcerm=True,
+            path=self.image.path, tag=self.image.canonical_name, decode=True,
+            network_mode=None, nocache=False, rm=True, pull=True, forcerm=True,
             buildargs=build_args)
 
         self.assertTrue(builder.success)
@@ -159,8 +217,8 @@ class TasksTest(base.TestCase):
         builder.run()
 
         mock_client().build.assert_called_once_with(
-            path=self.image.path, tag=self.image.canonical_name,
-            nocache=False, rm=True, pull=True, forcerm=True,
+            path=self.image.path, tag=self.image.canonical_name, decode=True,
+            network_mode=None, nocache=False, rm=True, pull=True, forcerm=True,
             buildargs=build_args)
 
         self.assertTrue(builder.success)
@@ -180,8 +238,8 @@ class TasksTest(base.TestCase):
         builder.run()
 
         mock_client().build.assert_called_once_with(
-            path=self.image.path, tag=self.image.canonical_name,
-            nocache=False, rm=True, pull=True, forcerm=True,
+            path=self.image.path, tag=self.image.canonical_name, decode=True,
+            network_mode=None, nocache=False, rm=True, pull=True, forcerm=True,
             buildargs=build_args)
 
         self.assertTrue(builder.success)
@@ -397,6 +455,110 @@ class KollaWorkerTest(base.TestCase):
         kolla = build.KollaWorker(self.conf)
         self.assertEqual(2, len(kolla.rpm_setup))
 
+    def test_build_distro_python_version_debian(self):
+        """check distro_python_version for Debian"""
+        self.conf.set_override('base', 'debian')
+        kolla = build.KollaWorker(self.conf)
+        self.assertEqual('2.7', kolla.distro_python_version)
+
+    def test_build_distro_python_version_rhel80(self):
+        """check distro_python_version for RHEL8.0"""
+        self.conf.set_override('base', 'rhel')
+        self.conf.set_override('base_tag', '8.0')
+        kolla = build.KollaWorker(self.conf)
+        self.assertEqual('3.6', kolla.distro_python_version)
+
+    def test_build_distro_python_version_rhel8(self):
+        """check distro_python_version for RHEL8"""
+        self.conf.set_override('base', 'rhel')
+        self.conf.set_override('base_tag', '8')
+        kolla = build.KollaWorker(self.conf)
+        self.assertEqual('3.6', kolla.distro_python_version)
+
+    def test_build_distro_python_version_ubuntu(self):
+        """check distro_python_version for Ubuntu"""
+        self.conf.set_override('base', 'ubuntu')
+        kolla = build.KollaWorker(self.conf)
+        self.assertEqual('2.7', kolla.distro_python_version)
+
+    def test_build_distro_python_version_centos7(self):
+        """check distro_python_version for CentOS 7.6.1810"""
+        self.conf.set_override('base', 'centos')
+        self.conf.set_override('base_tag', '7.6.1810')
+        kolla = build.KollaWorker(self.conf)
+        self.assertEqual('2.7', kolla.distro_python_version)
+
+    def test_build_distro_python_version_rhel7(self):
+        """check distro_python_version for RHEL7"""
+        self.conf.set_override('base', 'rhel')
+        self.conf.set_override('base_tag', '7')
+        kolla = build.KollaWorker(self.conf)
+        self.assertEqual('2.7', kolla.distro_python_version)
+
+    def test_build_distro_package_manager(self):
+        """check distro_package_manager conf value is taken"""
+        self.conf.set_override('distro_package_manager', 'foo')
+        kolla = build.KollaWorker(self.conf)
+        self.assertEqual('foo', kolla.distro_package_manager)
+
+    def test_build_distro_package_manager_rhel8(self):
+        """check distro_package_manager dnf for rhel8"""
+        self.conf.set_override('base', 'rhel')
+        self.conf.set_override('base_tag', '8')
+        kolla = build.KollaWorker(self.conf)
+        self.assertEqual('dnf', kolla.distro_package_manager)
+
+    def test_build_distro_package_manager_rhel8_minor(self):
+        """check distro_package_manager dnf for rhel8"""
+        self.conf.set_override('base', 'rhel')
+        self.conf.set_override('base_tag', '8.1.2')
+        kolla = build.KollaWorker(self.conf)
+        self.assertEqual('dnf', kolla.distro_package_manager)
+
+    def test_build_distro_package_manager_rhel7(self):
+        """check distro_package_manager yum for rhel7"""
+        self.conf.set_override('base', 'rhel')
+        self.conf.set_override('base_tag', '7')
+        kolla = build.KollaWorker(self.conf)
+        self.assertEqual('yum', kolla.distro_package_manager)
+
+    def test_build_distro_package_manager_rhel7_minor(self):
+        """check distro_package_manager yum for rhel7"""
+        self.conf.set_override('base', 'rhel')
+        self.conf.set_override('base_tag', '7.6.1801')
+        kolla = build.KollaWorker(self.conf)
+        self.assertEqual('yum', kolla.distro_package_manager)
+
+    def test_build_distro_package_manager_debian(self):
+        """check distro_package_manager apt for debian"""
+        self.conf.set_override('base', 'debian')
+        kolla = build.KollaWorker(self.conf)
+        self.assertEqual('apt', kolla.distro_package_manager)
+
+    def test_build_distro_package_manager_ubuntu(self):
+        """check distro_package_manager apt for ubuntu"""
+        self.conf.set_override('base', 'ubuntu')
+        kolla = build.KollaWorker(self.conf)
+        self.assertEqual('apt', kolla.distro_package_manager)
+
+    def test_base_package_type(self):
+        """check base_package_type conf value is taken"""
+        self.conf.set_override('base_package_type', 'pip')
+        kolla = build.KollaWorker(self.conf)
+        self.assertEqual('pip', kolla.base_package_type)
+
+    def test_base_package_type_rhel(self):
+        """check base_package_type rpm for rhel"""
+        self.conf.set_override('base', 'rhel')
+        kolla = build.KollaWorker(self.conf)
+        self.assertEqual('rpm', kolla.base_package_type)
+
+    def test_base_package_type_debian(self):
+        """check base_package_type deb for debian"""
+        self.conf.set_override('base', 'debian')
+        kolla = build.KollaWorker(self.conf)
+        self.assertEqual('deb', kolla.base_package_type)
+
     def test_pre_defined_exist_profile(self):
         # default profile include the fake image: image-base
         self.conf.set_override('profile', ['default'])
